@@ -7,7 +7,7 @@ from . import tools
 from .api import *
 from .bot import Bot
 from .connectors import *
-from .context import context as context
+from .context import context
 from .errors import *
 from .executors import *
 from .keyboards import *
