@@ -6,7 +6,8 @@
 from dataclasses import dataclass
 
 from .request import Request
-from .. import api, context
+from .. import api
+from ..context import context
 
 
 @dataclass(frozen=True)
