@@ -4,12 +4,14 @@
 
 
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import Optional, List
 
 from .inline_keyboard_markup import InlineKeyboardMarkup
 from .inline_query_result import InlineQueryResult
-from .parse_mode_type import ParseModeType
 from .input_message_content import InputMessageContent
+from .message_entity import MessageEntity
+from .parse_mode_type import ParseModeType
+from .thumb_mime_type import ThumbMimeType
 
 
 @dataclass(frozen=True)
@@ -24,11 +26,13 @@ class InlineQueryResultGif(InlineQueryResult):
     id: str
     gif_url: str
     thumb_url: str
+    thumb_mime_type: Optional[ThumbMimeType] = None
     gif_width: Optional[int] = None
     gif_height: Optional[int] = None
     gif_duration: Optional[int] = None
     title: Optional[str] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
+    caption_entities: Optional[List[MessageEntity]] = None
     reply_markup: Optional[InlineKeyboardMarkup] = None
     input_message_content: Optional[InputMessageContent] = None
