@@ -18,4 +18,7 @@ class InputLocationMessageContent(InputMessageContent):
 
     latitude: float
     longitude: float
+    horizontal_accuracy: Optional[float] = None
     live_period: Optional[int] = None
+    heading: Optional[int] = None
+    proximity_alert_radius: Optional[int] = None
