@@ -4,9 +4,10 @@
 
 
 from dataclasses import dataclass
-from typing import Optional
+from typing import Optional, List
 
 from .input_message_content import InputMessageContent
+from .message_entity import MessageEntity
 from .parse_mode_type import ParseModeType
 
 
@@ -19,4 +20,5 @@ class InputTextMessageContent(InputMessageContent):
 
     message_text: str
     parse_mode: Optional[ParseModeType] = None
+    entities: Optional[List[MessageEntity]] = None
     disable_web_page_preview: Optional[bool] = None
