@@ -2,7 +2,7 @@
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
-import warnings
+
 from dataclasses import dataclass
 from typing import Optional, Any
 
@@ -20,12 +20,6 @@ class Response:
     raw
     """
 
-    @property
-    def method(self) -> 'api.Request':
-        warnings.warn("This property is deprecated. Use request instead.", DeprecationWarning)
-
-        return self.request
-
     request: 'api.Request'
     raw: dict
     ok: bool
