@@ -24,6 +24,9 @@ class SendVenue(MessageResultMixin, Request):
     address: str
     foursquare_id: Optional[str] = None
     foursquare_type: Optional[str] = None
+    google_place_id: Optional[str] = None
+    google_place_type: Optional[str] = None
     disable_notification: Optional[bool] = None
     reply_to_message_id: Optional[int] = None
+    allow_sending_without_reply: Optional[bool] = None
     reply_markup: Optional[ALL_KEYBOARDS] = None
